@@ -45,7 +45,7 @@
 
 ;;; It's more advanced features include heavy use of `balloon-help' a
 ;;; package again written by Kyle Jones. You need to load this
-;;; explicitely on your own because I don't think a package should make
+;;; explicitly on your own because I don't think a package should make
 ;;; decisions which have a global effect (if you want to use it, a
 ;;; (require 'balloon-help) in your .emacs should work. But look at the
 ;;; documentation in balloon-help.el itself).
@@ -179,7 +179,7 @@ echo area instead of in the mode-line."
 
 (defcustom display-time-show-icons-maybe t
   "Use icons for time, load and mail status if possible
-and not specified different explicitely"
+and not specified different explicitly"
   :group 'display-time
   :type 'boolean)  
 
@@ -895,7 +895,7 @@ mail-text:     The same as above, but will not use a glyph"
 			 (string :tag "String"))))
 
 (defun display-time-evaluate-list ()
-  "Evalute the variable display-time-form-list"
+  "Evaluate the variable display-time-form-list"
   (let ((list display-time-form-list) elem tmp result)
     (while (setq elem (pop list))
       (cond ((stringp elem) (push elem tmp))
